General MX-Bluesky Developer Guide
==================================

Documentation is split into four categories, and each is also accessible from links in the side-bar.

.. grid:: 2
    :gutter: 2

    .. grid-item-card:: :material-regular:`description;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

            reference/param-hierarchy
            reference/readme
            deploying-hyperion

        +++

        Technical reference material on standards in use.
